Type Definition processes::function::RawFunctionPtrTarget
source · pub type RawFunctionPtrTarget = __some_function;Expand description
Type alias for the pointee of a raw function pointer.
pub type RawFunctionPtrTarget = __some_function;Type alias for the pointee of a raw function pointer.